/**
    Calculate the extents of desired fields, skipping `false`, `undefined`, `null` and `NaN` values
    For example, data like this:
    [{ x: 0, y: -10 }, { x: 10, y: 0 }, { x: 5, y: 10 }]
    and a fields object like this:
    `{'x': d => d.x, 'y': d => d.y}`
    returns an object like this:
    `{ x: [0, 10], y: [-10, 10] }`
    @param {Array} data A flat array of objects.
    @param {{x?: Function, y?: Function, z?: Function, r?: Function}} fields An object containing `x`, `y`, `r` or `z` keys that equal an accessor function. If an accessor function returns an array of values, each value will also be evaluated.
    @returns {{x?: [min: Number, max: Number]|[min: String, max: String], y?: [min: Number, max: Number]|[min: String, max: String], z?: [min: Number, max: Number]|[min: String, max: String], r?: [min: Number, max: Number]|[min: String, max: String]}} An object with the same structure as `fields` but instead of an accessor, each key contains an array of a min and a max.
*/
export default function calcExtents(data: any[], fields: {
    x?: Function;
    y?: Function;
    z?: Function;
    r?: Function;
}): {
    x?: [min: number, max: number] | [min: string, max: string] | undefined;
    y?: [min: number, max: number] | [min: string, max: string] | undefined;
    z?: [min: number, max: number] | [min: string, max: string] | undefined;
    r?: [min: number, max: number] | [min: string, max: string] | undefined;
};
